==> pgadmin4-9.8-x64.zip: pgAdmin 4.app/Contents/Frameworks/Python.framework/Versions/3.13/Frameworks/Tcl.framework/Versions/8.6/._tclooConfig.sh <==
    Mac OS X            	   2  /4     /f                                      ATTR      /f  L  .                 L     com.apple.cs.CodeDirectory       ,  com.apple.cs.CodeEntitlements      
D     com.apple.cs.CodeRequirements      
     com.apple.cs.CodeRequirements-1      #Z  com.apple.cs.CodeSignature                 4                     Iorg.pgadmin.pgadmin4 TCHGL2R7C5 (NEg;(P.(                                        B,4C}è\_6                    TUaEڛnZMX$~qq  ,<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <!--
        Disable Sandboxing. This must be enabled for the app store, but it will
        cause Electron to fail to start with an error like:

            [1004/170922.238911:ERROR:directory_reader_posix.cc(42)] opendir /dev/fd: Operation not permitted (1)

        We should figure out why that happens and fix it one day, but for now
        we just don't support the app store.
    -->
    <key>com.apple.security.app-sandbox</key>
    <false/>

    <!--
        Set the app group name for IPC and access to shared containers between
        our processes.
    -->
    <key>com.apple.security.application-groups</key>
    <string>TCHGL2R7C5.org.pgadmin.pgadmin4</string>

    <!--
        We have no need for JIT on x86_64, but Electron won't start without it
        on Apple Silicon.
    -->
    <key>com.apple.security.cs.allow-jit</key>
    <true/>

    <!--
        Explicitly disallow executable code overwriting/patching.
    -->
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <false/>

    <!--
        Explicitly disallow use of dynamic loader environment variables that
        could be used for code injection.
    -->
    <key>com.apple.security.cs.allow-dyld-environment-variables</key>
    <false/>

    <!--
        Explicitly ensure that library validation is enabled so we only load
        libraries and frameworks signed by us or Apple.
    -->
    <key>com.apple.security.cs.disable-library-validation</key>
    <false/>

    <!--
        We need to enable this, even though we don't modify our own executables.
        Otherwise, Electron just bombs out.
    -->
    <key>com.apple.security.cs.disable-executable-page-protection</key>
    <true/>

    <!--
        We're not a debugger (well, except for procedural languages in Postgres,
        but that doesn't count).
    -->
    <key>com.apple.security.cs.debugger</key>
    <false/>
</dict>
</plist>
                            org.pgadmin.pgadmin4                  
*Hcd                   
*Hcd
                
subject.OU        
TCHGL2R7C5               4                      Iorg.pgadmin.pgadmin4 TCHGL2R7C5 :F'./Na6洁8                                                                 Zh<W5|mhԭU'A}                                2LӁvKT=fwQ}0	*H
010
	`He 0	*H
  k00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00$]F0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
231127141403Z
270201221215Z010
	&,d
TCHGL2R7C51:08U1Developer ID Application: David Page (TCHGL2R7C5)10U
TCHGL2R7C510U

David Page10	UGB0"0
	*H
  0
 b5BvE}ɮKz:Pfxݛ:@%Ƀ$PnUc?KVZAC˔`qRI/"<9?DqlySV gg_?`[ǫ2af2
Ja1)o;mp{Rf'9$t7`1 r-KbkQS.̖xT#MG噢4A>A$SZuYTk󖢭o(APܖ	 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0UTaTd0D}eE0U0
*Hcd!20231127000000Z0
*Hcd
 0
	*H
  rnaXKyI7 :va=a1L2L-ZZL2eKh{I ʻ`HpUtƺݵMf
;i)wt6&tT!20$iD]8:ME<dj8eRr*Wo)~'
	'[B즚nC;$!10?AvfD?-oR`"}Z$6ui(5eRJ!1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS$]F0
	`He %0	*H
	1	*H
0	*H
	1
250902140634Z0/	*H
	1" i>ڵQdbwC۵3I+ֳtX몭0[	*Hcd	1N0+)_#\ztD6[$,a0-	`He G?VnruiΨRdW|Sx$0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		Ke5fI1x6h3T3RLG87hUYNlskLGE=
		</data>
		<data>
		6Uc/VshutgLlcpzUdedp3c6oUmQ=
		</data>
	</array>
</dict>
</plist>
0
	*H
  !BZE,M;}دm[MKtC>:tln= R'xeFj9	LOz; w!1e59dX63xHy
zF܀k|oikSۖExϝxt~4q|HĬӅv/TW\{7n*iC茷(QSif epHn!'L[]rU?"8eAaހcZY0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  9zk'@Sqj@ɱ*wr]7{h20250902140634Z0T&'
00;/{0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
250818174519Z
250929174518Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 1+9O3Pd"\3GA|$1du9b\D
hQg8CA4<bjMc|9L+(=\Ȅ`dK'*XeoJ?VY0fX?W:1UNW4T&T6SOܰu_,ʖFهΡD}%,)Պ~C7RGޮtSUyFfq#O
JcK})s 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U!?P
43nlo0U0
	*H
  ˖Sa	KaCq"bҚ&ߦpsi<hbTWn/  ?Ud={D<&XAY'8`I~L+ܴ޺/
!e;IKn;
XMajæuM;\))1q7TNΣ-A[7\--SQ}|л*'Kn@xZ/4*ؿHD,[00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS;/{0	+ 0	*H
	1
*H
	0	*H
	1
250902140634Z0#	*H
	1Yz-JXmĵ#V0+*H
	1000{?e9N ɵ-0
	*H
  #;V*2r,')0u+CpQ=	e@G&O/Q`nX=8ag ܑ&
^#>
9k)?rv|gWi 6=\%pY}ksaˡkWP
2J}-Eϕ숀="70|^=ZkvSR;lrإ[?{RjͭkN%kHtb,乫gO`      

==> pgadmin4-9.10-x64.zip: pgAdmin 4.app/Contents/Frameworks/Python.framework/Versions/3.13/Frameworks/Tcl.framework/Versions/8.6/._tclooConfig.sh <==
    Mac OS X            	   2  /     /                                      ATTR      /  l  .W                 l     com.apple.cs.CodeDirectory     8  ,  com.apple.cs.CodeEntitlements      
d     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1    ,  #[  com.apple.cs.CodeSignature     /   <  com.apple.quarantine               4                     Iorg.pgadmin.pgadmin4 TCHGL2R7C5 (NEg;(P.(                                        B,4C}è\_6                    TUaEڛnZMX$~qq  ,<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <!--
        Disable Sandboxing. This must be enabled for the app store, but it will
        cause Electron to fail to start with an error like:

            [1004/170922.238911:ERROR:directory_reader_posix.cc(42)] opendir /dev/fd: Operation not permitted (1)

        We should figure out why that happens and fix it one day, but for now
        we just don't support the app store.
    -->
    <key>com.apple.security.app-sandbox</key>
    <false/>

    <!--
        Set the app group name for IPC and access to shared containers between
        our processes.
    -->
    <key>com.apple.security.application-groups</key>
    <string>TCHGL2R7C5.org.pgadmin.pgadmin4</string>

    <!--
        We have no need for JIT on x86_64, but Electron won't start without it
        on Apple Silicon.
    -->
    <key>com.apple.security.cs.allow-jit</key>
    <true/>

    <!--
        Explicitly disallow executable code overwriting/patching.
    -->
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <false/>

    <!--
        Explicitly disallow use of dynamic loader environment variables that
        could be used for code injection.
    -->
    <key>com.apple.security.cs.allow-dyld-environment-variables</key>
    <false/>

    <!--
        Explicitly ensure that library validation is enabled so we only load
        libraries and frameworks signed by us or Apple.
    -->
    <key>com.apple.security.cs.disable-library-validation</key>
    <false/>

    <!--
        We need to enable this, even though we don't modify our own executables.
        Otherwise, Electron just bombs out.
    -->
    <key>com.apple.security.cs.disable-executable-page-protection</key>
    <true/>

    <!--
        We're not a debugger (well, except for procedural languages in Postgres,
        but that doesn't count).
    -->
    <key>com.apple.security.cs.debugger</key>
    <false/>
</dict>
</plist>
                            org.pgadmin.pgadmin4                  
*Hcd                   
*Hcd
                
subject.OU        
TCHGL2R7C5               4                      Iorg.pgadmin.pgadmin4 TCHGL2R7C5 :F'./Na6洁8                                                                 Zh<W5|mhԭU'A}                                2LӁvKT=fwQ}0	*H
010
	`He 0	*H
  k00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00$]F0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
231127141403Z
270201221215Z010
	&,d
TCHGL2R7C51:08U1Developer ID Application: David Page (TCHGL2R7C5)10U
TCHGL2R7C510U

David Page10	UGB0"0
	*H
  0
 b5BvE}ɮKz:Pfxݛ:@%Ƀ$PnUc?KVZAC˔`qRI/"<9?DqlySV gg_?`[ǫ2af2
Ja1)o;mp{Rf'9$t7`1 r-KbkQS.̖xT#MG噢4A>A$SZuYTk󖢭o(APܖ	 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0UTaTd0D}eE0U0
*Hcd!20231127000000Z0
*Hcd
 0
	*H
  rnaXKyI7 :va=a1L2L-ZZL2eKh{I ʻ`HpUtƺݵMf
;i)wt6&tT!20$iD]8:ME<dj8eRr*Wo)~'
	'[B즚nC;$!10?AvfD?-oR`"}Z$6ui(5eRJ!1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS$]F0
	`He %0	*H
	1	*H
0	*H
	1
251110092625Z0/	*H
	1" i>ڵQdbwC۵3I+ֳtX몭0[	*Hcd	1N0+)_#\ztD6[$,a0-	`He G?VnruiΨRdW|Sx$0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		Ke5fI1x6h3T3RLG87hUYNlskLGE=
		</data>
		<data>
		6Uc/VshutgLlcpzUdedp3c6oUmQ=
		</data>
	</array>
</dict>
</plist>
0
	*H
  re1>#v?9:J3
vUQk|ZNRa\	*Zٮ`C'B?t7,OhӹzGaFRټiBpb>fׄ,Ӆ=X؇}~[#OR[@j	,|-ro*QJòXBwPz9iu'<%ٓO7w^Zyb#2=6K`^yJ.H8{7fW&1RkwCA0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  &Fc.vubiH]hѻF'Z20251110092625Z0	 ژ\H
00@PК
0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
251013173521Z
251124173520Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 Jr5aG-ry]JcYjI9J@r<=;5Du>ch$ dnVL׿HTa˨KcnޕTc]fQ15)q۝3Xih",>VqѼdQI̟bJ@	3
n<{<w
5B\漗imSraolt9;Rѣˉ ]r*00^P(ɎF 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U"˺?EsD%/n̍N0U0
	*H
  o4lq7NƲ|#ӕV_N,4אjOۗcЏ;u|M$ȕ*0$He9QiJ`Z7{˾7u[:1J`J
6hrco3@Rm#R^ fHV08ڭ9m`ߣWЮ|ψu&wlNW^i``ARc,i]
arZX`*JxҵiZusV00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS@PК
0	+ 0	*H
	1
*H
	0	*H
	1
251110092625Z0#	*H
	1Ɋm-=(0+*H
	1000Oev
Ecm
<20
	*H
  5ժ	<9P6g9Ԟ'ŐlQiXW}{O0{{B('8Oư%EO 3<`kzL	D~ ɍs\4c/A=.e}3wu-oL0I0D͠&IU6M~_1rn4^pQu]nP#!i]>AVq {tE!Pd=ϱi`z>Bќ>}̱GA      q/0083;68e445db;Safari;D4948E6E-9DE1-4187-A0B6-C3D05B3684A0 
